@@ -20,11 +20,16 @@ class Conn:
         try:
             conn = pyodbc.connect(self.connection_string)
             cur = conn.cursor()
+            print(command)
+
             cur.execute(command)
             if 'SELECT' in command:
                 resp = cur.fetchall()
                 return list(resp)
             if 'UPDATE' in command:
                 conn.commit()
+            if 'INSERT' in command:
+                return True
+                conn.commit()
         except Exception as e:
             print(e)
